@@ -1,12 +1,15 @@
-from multimodal.datasets.coco import download
-from multimodal import DEFAULT_DATA_DIR
+import json
 import os
-from torchtext.data.utils import get_tokenizer
-import numpy as np
-from collections import defaultdict
 import pickle
 from typing import List
+from collections import defaultdict
+
 import torch
+import numpy as np
+from torchtext.data.utils import get_tokenizer
+
+from multimodal.datasets.coco import download
+from multimodal import DEFAULT_DATA_DIR
 
 
 class BasicTokenizer:
@@ -185,3 +188,27 @@ class BasicTokenizer:
 
     def get_num_tokens(self):
         return len(self.tokens)
+
+
+class AnswerMap:
+
+    base_url = "https://webia.lip6.fr/~dancette/multimodal/answermaps/{name}.json"
+
+    def __init__(self, answers) -> None:
+        self.answers = answers
+        self.ans2id = {ans: id for (id, ans) in enumerate(self.answers)}
+
+    def __getitem__(self, index):
+        return self.answers[index]
+
+    def get_answer_id(self, answer):
+        return self.ans2id[answer]
+
+    @classmethod
+    def from_pretrained(cls, name, dir_data=None):
+        dir_data = dir_data or DEFAULT_DATA_DIR
+        url = cls.base_url.format(name=name)
+        path = download(url, os.path.join(dir_data, "answermaps"))
+        with open(path) as f:
+            answers = json.load(f)
+        return AnswerMap(answers=answers)
